package main;

import java.io.*;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;

public class CsvBuilder {

    private static final String inputFile = "src/csv/credentials.csv";
    private static final String reportDirectory = "src/csv/reports/";
    private static String reportFilePath = null;

    private static String reportFile;
    public static void compileAll(String outputFile) {
        try (BufferedReader reader = new BufferedReader(new FileReader(inputFile));
             BufferedWriter writer = new BufferedWriter(new FileWriter("src/csv/built/" + outputFile + ".csv"))) {

            // Skip the first line
            reader.readLine();

            String line;
            while ((line = reader.readLine()) != null) {
                String[] parts = line.split(",", 2);
                if (parts.length > 1) {
                    writer.write(parts[1]);
                    writer.newLine();
                }
            }

            System.out.println("File processed successfully!");
        } catch (IOException e) {
            System.err.println("Error processing file: " + e.getMessage());
        }
    }

    public static void compilePermissions(String outputFile) {
        try (BufferedReader reader = new BufferedReader(new FileReader(inputFile));
             BufferedWriter writer = new BufferedWriter(new FileWriter("src/csv/built/" + outputFile + ".csv"))) {

            // Skip the first line
            reader.readLine();

            String line;
            while ((line = reader.readLine()) != null) {
                writer.write(line + "\n");
            }

            System.out.println("File processed successfully!");
        } catch (IOException e) {
            System.err.println("Error processing file: " + e.getMessage());
        }
    }

    public static String createTestReportFile() {
        DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyyMMdd-HHmmss");
        String timestamp = LocalDateTime.now().format(formatter);
        String filePath = "src/csv/reports/test-report-" + timestamp + ".csv";

        try (BufferedWriter writer = new BufferedWriter(new FileWriter(filePath))) {
            writer.write("Role,Username,Step,Result\n"); // header
        } catch (IOException e) {
            System.err.println("Failed to create report file: " + e.getMessage());
        }

        reportFile = filePath;
        return filePath;
    }

    public static void appendTestResult(String role, String username, String step, String result) {
        if (reportFile == null) {
            System.err.println("Report file not initialized.");
            return;
        }

        try (BufferedWriter writer = new BufferedWriter(new FileWriter(reportFile, true))) {
            writer.write(String.format("%s,%s,%s,%s\n", role, username, step, result));
        } catch (IOException e) {
            System.err.println("Failed to write to report file: " + e.getMessage());
        }
    }
    public static void main(String[] args) {
        CsvBuilder.compileAll("all_login_credentials");
        CsvBuilder.compilePermissions("credentials_permissions");
    }
}
